.. _interfaces_ref:

:mod:`nilearn.interfaces`: Loading components from interfaces
=============================================================

.. automodule:: nilearn.interfaces
   :no-members:
   :no-inherited-members:

:mod:`nilearn.interfaces.bids`
------------------------------

.. automodule:: nilearn.interfaces.bids
   :no-members:
   :no-inherited-members:

Functions
^^^^^^^^^

.. currentmodule:: nilearn.interfaces.bids

.. autosummary::
   :toctree: generated/
   :template: function.rst

   get_bids_files
   parse_bids_filename
   save_glm_to_bids

:mod:`nilearn.interfaces.fmriprep`
----------------------------------

.. automodule:: nilearn.interfaces.fmriprep
   :no-members:
   :no-inherited-members:

Functions
^^^^^^^^^

.. currentmodule:: nilearn.interfaces.fmriprep

.. autosummary::
   :toctree: generated/
   :template: function.rst

   load_confounds
   load_confounds_strategy

:mod:`nilearn.interfaces.fsl`
-----------------------------

.. automodule:: nilearn.interfaces.fsl
   :no-members:
   :no-inherited-members:

Functions
^^^^^^^^^

.. currentmodule:: nilearn.interfaces.fsl

.. autosummary::
   :toctree: generated/
   :template: function.rst

   get_design_from_fslmat
